@@ -15,7 +15,7 @@ import datetime
 import io
 import itertools
 import logging
-from numbers import Number
+import numbers
 import os
 import platform
 import shutil
@@ -76,10 +76,12 @@ def _map_parallel(function, args, n_jobs):
     if multiprocessing and int(n_jobs) not in (0, 1):
         if n_jobs == -1:
             n_jobs = None
-        pool = multiprocessing.Pool(processes=n_jobs)
-        map_result = pool.map(function, args)
-        pool.close()
-        pool.join()
+        try:
+            pool = multiprocessing.Pool(processes=n_jobs)
+            map_result = pool.map(function, args)
+        finally:
+            pool.close()
+            pool.join()
     else:
         map_result = list(map(function, args))
     return map_result
@@ -247,10 +249,10 @@ class StanModel:
             lib_dir,
             pystan_dir,
             os.path.join(pystan_dir, "stan", "src"),
-            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.14.0"),
-            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.14.0", "lib", "eigen_3.2.9"),
-            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.14.0", "lib", "boost_1.62.0"),
-            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.14.0", "lib", "cvodes_2.9.0", "include"),
+            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.15.0"),
+            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.15.0", "lib", "eigen_3.2.9"),
+            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.15.0", "lib", "boost_1.62.0"),
+            os.path.join(pystan_dir, "stan", "lib", "stan_math_2.15.0", "lib", "cvodes_2.9.0", "include"),
             np.get_include(),
         ]
 
@@ -475,7 +477,7 @@ class StanModel:
         del m_pars[idx_of_lp]
         del p_dims[idx_of_lp]
 
-        if isinstance(init, Number):
+        if isinstance(init, numbers.Number):
             init = str(init)
         elif isinstance(init, Callable):
             init = init()
@@ -556,6 +558,7 @@ class StanModel:
         algorithm : {"NUTS", "HMC", "Fixed_param"}, optional
             One of algorithms that are implemented in Stan such as the No-U-Turn
             sampler (NUTS, Hoffman and Gelman 2011), static HMC, or ``Fixed_param``.
+            Default is NUTS.
 
         init : {0, '0', 'random', function returning dict, list of dict}, optional
             Specifies how initial parameter values are chosen: 0 or '0'
@@ -659,6 +662,8 @@ class StanModel:
             data = {}
         if warmup is None:
             warmup = int(iter // 2)
+        if not all(isinstance(arg, numbers.Integral) for arg in (iter, thin, warmup)):
+            raise ValueError('only integer values allowed as `iter`, `thin`, and `warmup`.')
         algorithms = ("NUTS", "HMC", "Fixed_param")  # , "Metropolis")
         algorithm = "NUTS" if algorithm is None else algorithm
         if algorithm not in algorithms:
@@ -846,7 +851,7 @@ class StanModel:
         m_pars = fit._get_param_names()
         p_dims = fit._get_param_dims()
 
-        if isinstance(init, Number):
+        if isinstance(init, numbers.Number):
             init = str(init)
         elif isinstance(init, Callable):
             init = init()
@@ -886,4 +891,4 @@ class StanModel:
 
         logger.warning('Automatic Differentiation Variational Inference (ADVI) is an EXPERIMENTAL ALGORITHM.')
         logger.warning('ADVI samples may be found on the filesystem in the file `{}`'.format(sample.args['sample_file'].decode('utf8')))
-        return OrderedDict([('args', sample.args), ('mean_pars', sample.mean_pars)])
+        return OrderedDict([('args', sample.args), ('inits', sample.inits), ('sampler_params', sample.sampler_params), ('sampler_param_names', sample.sampler_param_names), ('mean_pars', sample.mean_pars)])
